@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-editable-toolbar.c 2595 2007-07-29 16:36:00Z carlosgc $
+ *  $Id: egg-editable-toolbar.c 3240 2008-10-27 12:17:08Z chpe $
  */
 
 #include "config.h"
@@ -25,26 +25,7 @@
 #include "egg-toolbars-model.h"
 #include "egg-toolbar-editor.h"
 
-#include <gtk/gtkvseparator.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtktoggleaction.h>
-#include <gtk/gtkcheckmenuitem.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtktoolbar.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtktoolbutton.h>
-#include <gtk/gtkseparatortoolitem.h>
-#include <gtk/gtkicontheme.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <string.h>
 
@@ -434,9 +415,13 @@ configure_item_cursor (GtkToolItem *item,
       if (priv->edit_mode > 0)
         {
           GdkCursor *cursor;
+	  GdkScreen *screen;
           GdkPixbuf *pixbuf = NULL;
-          
-          cursor = gdk_cursor_new (GDK_HAND2);
+
+	  screen = gtk_widget_get_screen (GTK_WIDGET (etoolbar));
+	  
+          cursor = gdk_cursor_new_for_display (gdk_screen_get_display (screen),
+					       GDK_HAND2);
           gdk_window_set_cursor (widget->window, cursor);
           gdk_cursor_unref (cursor);
 
@@ -1763,10 +1748,13 @@ new_pixbuf_from_widget (GtkWidget *widget)
   GdkVisual *visual;
   gint icon_width;
   gint icon_height;
+  GdkScreen *screen;
 
   icon_width = DEFAULT_ICON_WIDTH;
 
-  if (!gtk_icon_size_lookup_for_settings (gtk_settings_get_default (), 
+  screen = gtk_widget_get_screen (widget);
+
+  if (!gtk_icon_size_lookup_for_settings (gtk_settings_get_for_screen (screen),
 					  GTK_ICON_SIZE_LARGE_TOOLBAR,
 					  NULL, 
 					  &icon_height))
