@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-toolbar-editor.c 2617 2007-08-11 09:40:45Z carlosgc $
+ *  $Id: egg-toolbar-editor.c 3240 2008-10-27 12:17:08Z chpe $
  */
 
 #include "config.h"
@@ -25,14 +25,6 @@
 
 #include <string.h>
 #include <libxml/tree.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkhbox.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
