@@ -18,24 +18,23 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
-#include "ev-properties-view.h"
-#include "ev-document-fonts.h"
-
-#include <glib/gi18n.h>
-#include <gtk/gtk.h>
-#include <glade/glade.h>
-#include <time.h>
-#include <sys/time.h>
 #include <string.h>
+#include <sys/time.h>
+#include <time.h>
 
 #ifdef HAVE__NL_MEASUREMENT_MEASUREMENT
 #include <langinfo.h>
 #endif
 
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <glade/glade.h>
+
+#include "ev-properties-view.h"
+#include "ev-document-fonts.h"
+
 typedef enum
 {
 	TITLE_PROPERTY,
@@ -96,6 +95,8 @@ ev_properties_view_dispose (GObject *object)
 		g_object_unref (properties->xml);
 		properties->xml = NULL;
 	}
+
+	G_OBJECT_CLASS (ev_properties_view_parent_class)->dispose (object);
 }
 
 static void
@@ -191,138 +192,109 @@ set_property (GladeXML *xml, Property property, const char *text)
 	g_free (valid_text);
 }
 
-/*
- * All values are in mm. 
- * Source: http://en.wikipedia.org/wiki/Paper_size
- */
-struct regular_paper_size {
-	double width;
-	double height;
-	double width_tolerance;
-	double height_tolerance;
-	const char *description;
-} const regular_paper_sizes[] = {
-	// ISO 216 paper sizes
-	{  841.0f, 1189.0f, 3.0f, 3.0f, "A0"  },
-	{  594.0f,  841.0f, 2.0f, 3.0f, "A1"  },
-	{  420.0f,  594.0f, 2.0f, 2.0f, "A2"  },
-	{  297.0f,  420.0f, 2.0f, 2.0f, "A3"  },
-	{  210.0f,  297.0f, 2.0f, 2.0f, "A4"  },
-	{  148.0f,  210.0f, 1.5f, 2.0f, "A5"  },
-	{  105.0f,  148.0f, 1.5f, 1.5f, "A6"  },
-	{   74.0f,  105.0f, 1.5f, 1.5f, "A7"  },
-	{   52.0f,   74.0f, 1.5f, 1.5f, "A8"  },
-	{   37.0f,   52.0f, 1.5f, 1.5f, "A9"  },
-	{   26.0f,   37.0f, 1.5f, 1.5f, "A10" },
-	{ 1000.0f, 1414.0f, 3.0f, 3.0f, "B0"  },
-	{  707.0f, 1000.0f, 3.0f, 3.0f, "B1"  },
-	{  500.0f,  707.0f, 2.0f, 3.0f, "B2"  },
-	{  353.0f,  500.0f, 2.0f, 2.0f, "B3"  },
-	{  250.0f,  353.0f, 2.0f, 2.0f, "B4"  },
-	{  176.0f,  250.0f, 2.0f, 2.0f, "B5"  },
-	{  125.0f,  176.0f, 1.5f, 2.0f, "B6"  },
-	{   88.0f,  125.0f, 1.5f, 1.5f, "B7"  },
-	{   62.0f,   88.0f, 1.5f, 1.5f, "B8"  },
-	{   44.0f,   62.0f, 1.5f, 1.5f, "B9"  },
-	{   31.0f,   44.0f, 1.5f, 1.5f, "B10" },
-	{  917.0f, 1297.0f, 3.0f, 3.0f, "C0"  },
-	{  648.0f,  917.0f, 3.0f, 3.0f, "C1"  },
-	{  458.0f,  648.0f, 2.0f, 3.0f, "C2"  },
-	{  324.0f,  458.0f, 2.0f, 2.0f, "C3"  },
-	{  229.0f,  324.0f, 2.0f, 2.0f, "C4"  },
-	{  162.0f,  229.0f, 2.0f, 2.0f, "C5"  },
-	{  114.0f,  162.0f, 1.5f, 2.0f, "C6"  },
-	{   81.0f,  114.0f, 1.5f, 1.5f, "C7"  },
-	{   57.0f,   81.0f, 1.5f, 1.5f, "C8"  },
-	{   40.0f,   57.0f, 1.5f, 1.5f, "C9"  },
-	{   28.0f,   40.0f, 1.5f, 1.5f, "C10" },
-
-	// US paper sizes
-	{  279.0f,  216.0f, 3.0f, 3.0f, "Letter" },
-	{  356.0f,  216.0f, 3.0f, 3.0f, "Legal"  },
-	{  432.0f,  279.0f, 3.0f, 3.0f, "Ledger" }
-};
-
-typedef enum {
-  EV_UNIT_INCH,
-  EV_UNIT_MM
-} EvUnit; 
-
-static EvUnit
-ev_get_default_user_units (void)
+static GtkUnit
+get_default_user_units (void)
 {
-  /* Translate to the default units to use for presenting
-   * lengths to the user. Translate to default:inch if you
-   * want inches, otherwise translate to default:mm.
-   * Do *not* translate it to "predefinito:mm", if it
-   * it isn't default:mm or default:inch it will not work
-   */
-  gchar *e = _("default:mm");
+	/* Translate to the default units to use for presenting
+	 * lengths to the user. Translate to default:inch if you
+	 * want inches, otherwise translate to default:mm.
+	 * Do *not* translate it to "predefinito:mm", if it
+	 * it isn't default:mm or default:inch it will not work
+	 */
+	gchar *e = _("default:mm");
 
 #ifdef HAVE__NL_MEASUREMENT_MEASUREMENT
-  gchar *imperial = NULL;
-
-  imperial = nl_langinfo (_NL_MEASUREMENT_MEASUREMENT);
-  if (imperial && imperial[0] == 2 )
-    return EV_UNIT_INCH;  /* imperial */
-  if (imperial && imperial[0] == 1 )
-    return EV_UNIT_MM;  /* metric */
+	gchar *imperial = NULL;
+	
+	imperial = nl_langinfo (_NL_MEASUREMENT_MEASUREMENT);
+	if (imperial && imperial[0] == 2)
+		return GTK_UNIT_INCH;  /* imperial */
+	if (imperial && imperial[0] == 1)
+		return GTK_UNIT_MM;  /* metric */
 #endif
 
-  if (strcmp (e, "default:inch")==0)
-    return EV_UNIT_INCH;
-  else if (strcmp (e, "default:mm"))
-    g_warning ("Whoever translated default:mm did so wrongly.\n");
-  return EV_UNIT_MM;
+	if (strcmp (e, "default:mm") == 0)
+		return GTK_UNIT_MM;
+	if (strcmp (e, "default:inch") == 0)
+		return GTK_UNIT_INCH;
+	
+	g_warning ("Whoever translated default:mm did so wrongly.\n");
+				
+	return GTK_UNIT_MM;
+}
+
+static gdouble
+get_tolerance (gdouble size)
+{
+	if (size < 150.0f)
+		return 1.5f;
+	else if (size >= 150.0f && size <= 600.0f)
+		return 2.0f;
+	else
+		return 3.0f;
 }
 
 static char *
 ev_regular_paper_size (const EvDocumentInfo *info)
 {
-	const struct regular_paper_size *size;   
-	EvUnit unit;
-	char *exact_size = NULL;
-	char *str = NULL;
-	int i;
+	GList *paper_sizes, *l;
+	gchar *exact_size;
+	gchar *str = NULL;
+	GtkUnit units;
 
-	unit = ev_get_default_user_units ();	
+	units = get_default_user_units ();
 
-	if (unit == EV_UNIT_INCH)
-		/* Imperial measurement (inches) */
-		exact_size = g_strdup_printf( _("%.2f x %.2f in"),
+	if (units == GTK_UNIT_MM) {
+		exact_size = g_strdup_printf(_("%.0f x %.0f mm"),
+					     info->paper_width,
+					     info->paper_height);
+	} else {
+		exact_size = g_strdup_printf (_("%.2f x %.2f inch"),
 					      info->paper_width  / 25.4f,
-					      info->paper_height / 25.4f );
-	else
-		/* Metric measurement (millimeters) */
-		exact_size = g_strdup_printf( _("%.0f x %.0f mm"),
-					      info->paper_width,
-					      info->paper_height );
-	
-	for (i = G_N_ELEMENTS ( regular_paper_sizes ) - 1; i >= 0; i--) {
-		size = &regular_paper_sizes[i];
+					      info->paper_height / 25.4f);
+	}
 
-		if ( ABS( info->paper_height - size->height ) <= size->height_tolerance &&
-		     ABS( info->paper_width  - size->width  ) <= size->width_tolerance ) {
+	paper_sizes = gtk_paper_size_get_paper_sizes (FALSE);
+	
+	for (l = paper_sizes; l && l->data; l = g_list_next (l)) {
+		GtkPaperSize *size = (GtkPaperSize *) l->data;
+		gdouble paper_width;
+		gdouble paper_height;
+		gdouble width_tolerance;
+		gdouble height_tolerance;
+
+		paper_width = gtk_paper_size_get_width (size, GTK_UNIT_MM);
+		paper_height = gtk_paper_size_get_height (size, GTK_UNIT_MM);
+
+		width_tolerance = get_tolerance (paper_width);
+		height_tolerance = get_tolerance (paper_height);
+
+		if (ABS (info->paper_height - paper_height) <= height_tolerance &&
+		    ABS (info->paper_width  - paper_width) <= width_tolerance) {
 			/* Note to translators: first placeholder is the paper name (eg.
 			 * A4), second placeholder is the paper size (eg. 297x210 mm) */
-			str = g_strdup_printf ( _("%s, Portrait (%s)"),
-						size->description,
-						exact_size );
-		} else if ( ABS( info->paper_width  - size->height ) <= size->height_tolerance &&
-			    ABS( info->paper_height - size->width  ) <= size->width_tolerance ) {
+			str = g_strdup_printf (_("%s, Portrait (%s)"),
+					       gtk_paper_size_get_display_name (size),
+					       exact_size);
+		} else if (ABS (info->paper_width  - paper_height) <= height_tolerance &&
+			   ABS (info->paper_height - paper_width) <= width_tolerance) {
 			/* Note to translators: first placeholder is the paper name (eg.
 			 * A4), second placeholder is the paper size (eg. 297x210 mm) */
 			str = g_strdup_printf ( _("%s, Landscape (%s)"),
-						size->description,
-						exact_size );
+						gtk_paper_size_get_display_name (size),
+						exact_size);
 		}
 	}
 
+	g_list_foreach (paper_sizes, (GFunc) gtk_paper_size_free, NULL);
+	g_list_free (paper_sizes);
+
 	if (str != NULL) {
 		g_free (exact_size);
 		return str;
-	} else
-		return exact_size;
+	}
+	
+	return exact_size;
 }
 
 void
